@@ -32,14 +32,14 @@ from gajim.common.helpers import get_tls_error_phrases
 from gajim.common.helpers import load_file_async
 from gajim.common.helpers import write_file_async
 from gajim.common.i18n import _
+from gajim.common.image_helpers import create_thumbnail
+from gajim.common.image_helpers import get_pixbuf_from_data
 from gajim.common.preview_helpers import aes_decrypt
-from gajim.common.preview_helpers import create_thumbnail
 from gajim.common.preview_helpers import filename_from_uri
 from gajim.common.preview_helpers import get_image_paths
 from gajim.common.preview_helpers import get_previewable_mime_types
 from gajim.common.preview_helpers import guess_mime_type
 from gajim.common.preview_helpers import parse_fragment
-from gajim.common.preview_helpers import pixbuf_from_data
 from gajim.common.preview_helpers import split_geo_uri
 from gajim.common.storage.archive import models as mod
 from gajim.common.types import GdkPixbufType
@@ -425,7 +425,7 @@ class PreviewManager:
         preview.file_size = os.path.getsize(preview.orig_path)
 
         try:
-            pixbuf = pixbuf_from_data(preview.thumbnail)
+            pixbuf = get_pixbuf_from_data(preview.thumbnail)
         except Exception as err:
             log.error('Unable to load: %s, %s',
                       preview.thumb_path.name,
@@ -613,7 +613,7 @@ class PreviewManager:
             return
 
         try:
-            pixbuf = pixbuf_from_data(preview.thumbnail)
+            pixbuf = get_pixbuf_from_data(preview.thumbnail)
         except Exception as err:
             log.error('Unable to load: %s, %s',
                       preview.thumb_path.name,
