@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
@@ -481,8 +471,9 @@ class Gateway(Page):
 
     def _on_command_clicked(self, _button: Gtk.Button) -> None:
         assert self._result is not None
-        open_window(
-            'AdHocCommands', account=self._account, jid=str(self._result.jid))
+        open_window('AdHocCommands',
+                    account=self._account,
+                    jids=[str(self._result.jid)])
 
 
 class GroupChat(Page):
