@@ -67,7 +67,6 @@ from gajim.gtk import structs
 from gajim.gtk.about import AboutDialog
 from gajim.gtk.accounts import AccountsWindow
 from gajim.gtk.avatar import AvatarStorage
-from gajim.gtk.builder import get_builder
 from gajim.gtk.const import ACCOUNT_ACTIONS
 from gajim.gtk.const import ALWAYS_ACCOUNT_ACTIONS
 from gajim.gtk.const import APP_ACTIONS
@@ -79,6 +78,7 @@ from gajim.gtk.dialogs import DialogButton
 from gajim.gtk.dialogs import ErrorDialog
 from gajim.gtk.dialogs import ShortcutsWindow
 from gajim.gtk.discovery import ServiceDiscoveryWindow
+from gajim.gtk.menus import get_main_menu
 from gajim.gtk.start_chat import StartChatDialog
 from gajim.gtk.util import get_app_window
 from gajim.gtk.util import get_app_windows
@@ -225,8 +225,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
         icon_theme.append_search_path(str(configpaths.get('ICONS')))
         load_user_iconsets()
 
-        builder = get_builder('application_menu.ui')
-        self.set_menubar(cast(Gio.Menu, builder.get_object('menubar')))
+        self.set_menubar(get_main_menu())
 
         from gajim.gtk import notification
         notification.init()
@@ -527,8 +526,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     def create_account(self,
                        account: str,
-                       username: str | None,
-                       domain: str,
+                       address: JID,
                        password: str,
                        proxy_name: str | None,
                        custom_host: tuple[str,
@@ -539,8 +537,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         CoreApplication.create_account(self,
                                        account,
-                                       username,
-                                       domain,
+                                       address,
                                        password,
                                        proxy_name,
                                        custom_host,
@@ -646,7 +643,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
     def _on_services_action(_action: Gio.SimpleAction,
                             param: GLib.Variant) -> None:
         account = param.get_string()
-        server_jid = app.settings.get_account_setting(account, 'hostname')
+        server_jid = app.get_hostname_from_account(account)
         if account not in app.interface.instances:
             app.interface.instances[account] = {'disco': {}}
 
