@@ -24,12 +24,12 @@ from gajim.common import app
 from gajim.common.const import AvatarSize
 from gajim.common.helpers import get_file_path_from_dnd_dropped_uri
 from gajim.common.i18n import _
+from gajim.common.image_helpers import scale_with_ratio
 
 from gajim.gtk import types
 from gajim.gtk.const import TARGET_TYPE_URI_LIST
 from gajim.gtk.dialogs import ErrorDialog
 from gajim.gtk.filechoosers import AvatarChooserDialog
-from gajim.gtk.util import scale_with_ratio
 
 log = logging.getLogger('gajim.gtk.avatar_selector')
 
