@@ -54,6 +54,7 @@ from gajim.gtk.dialogs import DialogButton
 from gajim.gtk.dialogs import ErrorDialog
 from gajim.gtk.dialogs import InputDialog
 from gajim.gtk.filechoosers import FileSaveDialog
+from gajim.gtk.main_menu_button import MainMenuButton
 from gajim.gtk.main_stack import MainStack
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import actionmethod
@@ -100,6 +101,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         self._chat_page = self._main_stack.get_chat_page()
 
+        self._ui.left_grid.attach(MainMenuButton(), 0, 0, 1, 1)
+
         self._app_page = self._main_stack.get_app_page()
         self._app_side_bar = AppSideBar(self._app_page)
         self._ui.app_box.add(self._app_side_bar)
@@ -335,7 +338,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
               'conversations will not be encrypted. Connecting PLAIN is '
               'strongly discouraged.') % {
                   'account': event.account,
-                  'server': app.get_hostname_from_account(event.account)},
+                  'server': app.get_hostname_from_account(
+                    event.account, prefer_custom=True)},
             [DialogButton.make('Cancel',
                                text=_('_Abort'),
                                callback=event.abort),
