@@ -17,9 +17,11 @@
 from __future__ import annotations
 
 from typing import Any
+from typing import TYPE_CHECKING
 
 import hashlib
 import logging
+import platform
 import sys
 import textwrap
 from pathlib import Path
@@ -47,15 +49,30 @@ from gajim.common.i18n import _
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import ResourceContact
 
+from gajim.gtk.avatar import merge_avatars
 from gajim.gtk.builder import get_builder
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import OpenEventActionParams
 from gajim.gtk.util import add_css_to_widget
 from gajim.gtk.util import get_total_screen_geometry
+from gajim.gtk.util import load_icon_surface
+
+if sys.platform == 'win32' or TYPE_CHECKING:
+    import winreg
+
+    from windows_toasts import InteractableWindowsToaster
+    from windows_toasts import Toast
+    from windows_toasts import ToastActivatedEventArgs
+    from windows_toasts import ToastButton
+    from windows_toasts import ToastDisplayImage
+    from windows_toasts import ToastImage
+    from windows_toasts import ToastImagePosition
+
+MIN_WINDOWS_TOASTS_WIN_VERSION = 10240
+WINDOWS_TOAST_NOTIFIER_AUMID = 'Gajim.ToastNotification'
 
 log = logging.getLogger('gajim.gtk.notification')
 
-
 NOTIFICATION_ICONS: dict[str, str] = {
     'incoming-message': 'gajim-chat-msg-recv',
     'group-chat-invitation': 'gajim-group-chat-invitation',
@@ -134,7 +151,7 @@ class DummyBackend(NotificationBackend):
         pass
 
 
-class Windows(NotificationBackend):
+class WindowsLegacy(NotificationBackend):
     def __init__(self):
         NotificationBackend.__init__(self)
         self._active_notification = None
@@ -186,7 +203,7 @@ class PopupNotification(Gtk.Window):
 
         if event.type == 'incoming-message':
             assert event.jid is not None
-            pixbuf = _get_pixbuf_icon(event.account, event.jid)
+            pixbuf = _get_pixbuf_icon(event.account, event.jid, event.resource)
             self._ui.image.set_from_pixbuf(pixbuf)
         else:
             icon_name = self._get_icon_name(event)
@@ -268,6 +285,147 @@ class PopupNotification(Gtk.Window):
             GLib.source_remove(self._timeout_id)
 
 
+class WindowsToastNotification(NotificationBackend):
+    def __init__(self):
+        NotificationBackend.__init__(self)
+        self._register_notifier_aumid()
+
+        self._toaster = InteractableWindowsToaster(
+            applicationText='Gajim',
+            notifierAUMID=WINDOWS_TOAST_NOTIFIER_AUMID
+        )
+
+    def _register_notifier_aumid(self) -> None:
+        '''Register an AUMID for Gajim's toast notifications.
+        This allows notifications issued by Gajim to have the right icon and title.
+        Code taken from: https://github.com/DatGuy1/Windows-Toasts/blob/main/scripts/register_hkey_aumid.py
+        '''
+        key_path = f'SOFTWARE\\Classes\\AppUserModelId\\{WINDOWS_TOAST_NOTIFIER_AUMID}'
+
+        image_path = (
+            Path(sys.executable).parent.parent
+            / 'share'
+            / 'icons'
+            / 'hicolor'
+            / '96x96'
+            / 'apps'
+            / 'org.gajim.Gajim.png'
+        )
+        winreg.ConnectRegistry(None, winreg.HKEY_CURRENT_USER)
+        with winreg.CreateKeyEx(winreg.HKEY_CURRENT_USER, key_path) as master_key:
+            winreg.SetValueEx(master_key, 'DisplayName', 0, winreg.REG_SZ, 'Gajim')
+            winreg.SetValueEx(
+                master_key,
+                'IconUri',
+                0,
+                winreg.REG_SZ,
+                str(image_path.resolve())
+            )
+
+    def _send(self, event: events.Notification) -> None:
+        toast = Toast()
+        toast.text_fields = [
+            event.title,
+            event.text
+        ]
+
+        toast_image = self._get_toast_image(event)
+        toast_display_image = ToastDisplayImage(
+            image=toast_image,
+            position=ToastImagePosition.AppLogo,
+        )
+        toast.AddImage(toast_display_image)
+
+        for button in self._get_toast_buttons(event):
+            toast.AddAction(button)
+
+        toast.on_activated = self._on_activated
+
+        self._toaster.show_toast(toast)
+
+    def _withdraw(self, details: list[Any]) -> None:
+        self._toaster.clear_toasts()
+
+    def _on_activated(self, event: ToastActivatedEventArgs) -> None:
+        # Calls need to be executed with GLib.idle_add to avoid threading issues,
+        # because Toasts run in a different thread.
+        if event.arguments is None:
+            GLib.idle_add(app.window.present_with_time, Gtk.get_current_event_time())
+            return
+
+        if event.arguments.startswith('open-event-'):
+            serialized_data = event.arguments.split('open-event-')[1]
+            params = OpenEventActionParams.from_serialized_string(
+                serialized_data, GLib.VariantType('a{sv}'))
+            if params is not None:
+                GLib.idle_add(
+                    app.app.activate_action,
+                    f'{params.account}-open-event',
+                    params.to_variant()
+                )
+                return
+
+        elif event.arguments.startswith('mark-as-read-'):
+            serialized_data = event.arguments.split('mark-as-read-')[1]
+            params = AccountJidParam.from_serialized_string(
+                serialized_data, GLib.VariantType('a{sv}'))
+            if params is not None:
+                GLib.idle_add(
+                    app.app.activate_action,
+                    f'{params.account}-mark-as-read',
+                    params.to_variant()
+                )
+                return
+
+        GLib.idle_add(app.window.present_with_time, Gtk.get_current_event_time())
+
+    def _get_toast_image(self, event: events.Notification) -> ToastImage:
+        if event.type == 'incoming-message':
+            assert event.jid is not None
+            surface = _get_surface_for_notification(
+                event.account, event.jid, event.resource)
+            return ToastImage(_get_path_for_icon(surface))
+
+        if event.icon_name is not None:
+            surface = load_icon_surface(event.icon_name, 32)
+            assert surface is not None
+            return ToastImage(_get_path_for_icon(surface))
+
+        icon_name = event.sub_type or event.type
+        icon_name = NOTIFICATION_ICONS.get(icon_name, 'mail-unread')
+        surface = load_icon_surface(icon_name, 32)
+        assert surface is not None
+        return ToastImage(_get_path_for_icon(surface))
+
+    def _get_toast_buttons(self, event: events.Notification) -> list[ToastButton]:
+        toast_buttons: list[ToastButton] = []
+
+        jid = '' if event.jid is None else str(event.jid)
+
+        params = OpenEventActionParams(type=event.type,
+                                       sub_type=event.sub_type or '',
+                                       account=event.account,
+                                       jid=jid)
+
+        button = ToastButton(
+            content=_('Open'),
+            arguments=f'open-event-{params.serialize()}'
+        )
+        toast_buttons.append(button)
+
+        if event.type == 'incoming-message':
+            assert isinstance(event.jid, JID)
+            params = AccountJidParam(account=event.account, jid=event.jid)
+
+            button = ToastButton(
+                content=_('Mark as Read'),
+                arguments=f'mark-as-read-{params.serialize()}'
+            )
+            toast_buttons.append(button)
+
+        return toast_buttons
+
+
 class Linux(NotificationBackend):
 
     _action_types = [
@@ -393,9 +551,9 @@ class Linux(NotificationBackend):
             assert event.jid is not None
 
             if app.is_flatpak():
-                return _get_bytes_icon(event.account, event.jid)
+                return _get_bytes_icon(event.account, event.jid, event.resource)
 
-            return _get_file_icon(event.account, event.jid)
+            return _get_file_icon(event.account, event.jid, event.resource)
 
         if event.icon_name is not None:
             return Gio.ThemedIcon.new(event.icon_name)
@@ -417,21 +575,37 @@ class Linux(NotificationBackend):
         return ','.join(map(str, details))
 
 
+def _get_participant_surface(
+        gc_contact: GroupchatContact,
+        resource: str) -> cairo.ImageSurface:
+    size = AvatarSize.NOTIFICATION
+    muc_avatar = gc_contact.get_avatar(size, 1)
+    participant_avatar = gc_contact.get_resource(resource).get_avatar(
+        size, 1, add_show=False)
+
+    return merge_avatars(muc_avatar, participant_avatar)
+
+
 def _get_surface_for_notification(account: str,
-                                  jid: JID | str) -> cairo.ImageSurface:
+                                  jid: JID | str,
+                                  resource: str | None) -> cairo.ImageSurface:
     size = AvatarSize.NOTIFICATION
     client = app.get_client(account)
     contact = client.get_module('Contacts').get_contact(jid)
     if isinstance(contact, GroupchatContact):
-        return contact.get_avatar(size, 1)
+        if resource:
+            return _get_participant_surface(contact, resource)
+        else:
+            return contact.get_avatar(size, 1)
 
     assert not isinstance(contact, ResourceContact)
     return contact.get_avatar(size, 1, add_show=False)
 
 
-def _get_pixbuf_icon(account: str, jid: JID | str) -> GdkPixbuf.Pixbuf:
+def _get_pixbuf_icon(
+        account: str, jid: JID | str, resource: str | None) -> GdkPixbuf.Pixbuf:
     size = AvatarSize.NOTIFICATION
-    surface = _get_surface_for_notification(account, jid)
+    surface = _get_surface_for_notification(account, jid, resource)
     pixbuf = Gdk.pixbuf_get_from_surface(surface,
                                          0,
                                          0,
@@ -441,14 +615,16 @@ def _get_pixbuf_icon(account: str, jid: JID | str) -> GdkPixbuf.Pixbuf:
     return pixbuf
 
 
-def _get_bytes_icon(account: str, jid: JID | str) -> Gio.BytesIcon:
-    pixbuf = _get_pixbuf_icon(account, jid)
+def _get_bytes_icon(
+        account: str, jid: JID | str, resource: str | None) -> Gio.BytesIcon:
+    pixbuf = _get_pixbuf_icon(account, jid, resource)
     _, data = pixbuf.save_to_bufferv('png')
     return Gio.BytesIcon(bytes=GLib.Bytes.new(data))
 
 
-def _get_file_icon(account: str, jid: JID | str) -> Gio.FileIcon:
-    surface = _get_surface_for_notification(account, jid)
+def _get_file_icon(
+        account: str, jid: JID | str, resource: str | None) -> Gio.FileIcon:
+    surface = _get_surface_for_notification(account, jid, resource)
     path = _get_path_for_icon(surface)
     return Gio.FileIcon(file=Gio.File.new_for_path(str(path)))
 
@@ -463,7 +639,9 @@ def _get_path_for_icon(surface: cairo.ImageSurface) -> Path:
 
 def get_notification_backend() -> NotificationBackend:
     if sys.platform == 'win32':
-        return Windows()
+        if int(platform.version().split('.')[2]) < MIN_WINDOWS_TOASTS_WIN_VERSION:
+            return WindowsLegacy()
+        return WindowsToastNotification()
 
     if sys.platform == 'darwin':
         return DummyBackend()
