@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
@@ -55,9 +45,12 @@ from gajim.gtk.chat_filter import ChatFilter
 from gajim.gtk.groupchat_info import GroupChatInfoScrolled
 from gajim.gtk.groupchat_nick import NickChooser
 from gajim.gtk.menus import get_start_chat_row_menu
+from gajim.gtk.tooltips import ContactTooltip
 from gajim.gtk.util import AccountBadge
 from gajim.gtk.util import GajimPopover
 from gajim.gtk.util import get_icon_name
+from gajim.gtk.util import GroupBadge
+from gajim.gtk.util import IdleBadge
 
 ContactT = BareContact | GroupchatContact
 
@@ -416,7 +409,10 @@ class StartChatDialog(Gtk.ApplicationWindow):
             self._show_error_page(_('This address is not reachable.'))
             return
 
-        if result.is_muc:
+        if result.is_muc and not result.jid.is_domain:
+            # This is mostly a fix for the MUC protocol, there is no
+            # way to differentiate between a MUC service and room.
+            # Except the MUC XEP defines rooms should have a localpart.
             row.update_chat_type(groupchat=True)
         else:
             row.update_chat_type()
@@ -556,7 +552,7 @@ class StartChatDialog(Gtk.ApplicationWindow):
             search_entry.set_text(uri.data['jid'])
             return
 
-        if '@' in search_text:
+        if search_text:
             try:
                 validate_jid(search_text)
             except ValueError:
@@ -734,7 +730,7 @@ class StartChatDialog(Gtk.ApplicationWindow):
                                parameters: bool = False
                                ) -> None:
         if self._search_stopped:
-            raise CancelledError()
+            raise CancelledError
 
         if is_error(result):
             assert isinstance(result, StanzaError)
@@ -784,38 +780,60 @@ class ContactRow(Gtk.ListBoxRow):
         image.set_size_request(AvatarSize.CHAT, AvatarSize.CHAT)
         grid.add(image)
 
-        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=0)
-        box.set_hexpand(True)
+        self._tooltip = ContactTooltip()
+        image.set_has_tooltip(True)
+        image.connect('query-tooltip', self._on_query_tooltip)
 
         if self.name is None:
             self.name = _('Start New Chat')
 
+        meta_box = Gtk.Box(
+            orientation=Gtk.Orientation.VERTICAL, valign=Gtk.Align.CENTER)
+
         self.name_label = Gtk.Label(label=self.name)
         self.name_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.name_label.set_xalign(0)
         self.name_label.set_width_chars(20)
         self.name_label.set_halign(Gtk.Align.START)
-        self.name_label.get_style_context().add_class('bold16')
-        name_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=6)
-        name_box.add(self.name_label)
+        self.name_label.get_style_context().add_class('bold14')
+        meta_box.add(self.name_label)
+
+        if contact and not contact.is_groupchat:
+            if idle := contact.idle_datetime:
+                idle_badge = IdleBadge(idle)
+                meta_box.add(idle_badge)
+
+        if contact and not contact.is_groupchat and (status := contact.status):
+            self.status_label = Gtk.Label(
+                label=status,
+                ellipsize=Pango.EllipsizeMode.END,
+                xalign=0,
+                width_chars=22,
+                halign=Gtk.Align.START,
+            )
+            self.status_label.get_style_context().add_class('dim-label')
+            self.status_label.get_style_context().add_class('small-label')
+            meta_box.add(self.status_label)
+
+        grid.attach(meta_box, 1, 0, 1, 3)
+
+        badge_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6)
         if show_account:
             account_badge = AccountBadge(account)
             account_badge.set_halign(Gtk.Align.END)
             account_badge.set_valign(Gtk.Align.START)
             account_badge.set_hexpand(True)
-            name_box.add(account_badge)
-        box.add(name_box)
+            badge_box.add(account_badge)
 
-        self.jid_label = Gtk.Label(label=str(jid))
-        self.jid_label.set_tooltip_text(str(jid))
-        self.jid_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self.jid_label.set_xalign(0)
-        self.jid_label.set_width_chars(22)
-        self.jid_label.set_halign(Gtk.Align.START)
-        self.jid_label.get_style_context().add_class('dim-label')
-        box.add(self.jid_label)
+        if contact and not contact.is_groupchat and not contact.is_pm_contact:
+            groups = contact.groups
+            for group in groups:
+                group_badge = GroupBadge(group)
+                badge_box.add(group_badge)
 
-        grid.add(box)
+        grid.attach(badge_box, 2, 0, 1, 3)
+
+        self._grid = grid
 
         eventbox = Gtk.EventBox()
         eventbox.connect('button-press-event', self._popup_menu)
@@ -823,6 +841,18 @@ class ContactRow(Gtk.ListBoxRow):
         self.add(eventbox)
         self.show_all()
 
+    def _on_query_tooltip(self,
+                          _img: Gtk.Image,
+                          _x_coord: int,
+                          _y_coord: int,
+                          _keyboard_mode: bool,
+                          tooltip: Gtk.Tooltip) -> bool:
+        if not isinstance(self.contact, BareContact):
+            return False
+        v, widget = self._tooltip.get_tooltip(self.contact)
+        tooltip.set_custom(widget)
+        return v
+
     def _popup_menu(self,
                     _widget: Gtk.EventBox,
                     event: Gdk.EventButton
@@ -852,7 +882,7 @@ class ContactRow(Gtk.ListBoxRow):
 
     def update_jid(self, jid: JID) -> None:
         self.jid = jid
-        self.jid_label.set_text(str(jid))
+        self._grid.set_tooltip_text(str(jid))
 
     def update_chat_type(self, groupchat: bool = False) -> None:
         self.is_new = False
