@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from typing import Any
 
@@ -287,7 +277,7 @@ class ValueLabel(Gtk.Label):
             self.set_text(value)
             return
         self._uri = puri
-        super().set_markup('<a href="{}">{}</a>'.format(
+        super().set_markup('<a href="{}">{}</a>'.format(  # noqa: UP032
             GLib.markup_escape_text(uri),
             GLib.markup_escape_text(value)))
 
