@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
@@ -131,7 +121,7 @@ class PluginManager(metaclass=Singleton):
                     log.warning('Error while updating plugin')
                     continue
 
-                self.add_plugin(manifest, activate=True)
+                self._add_plugin(manifest, activate=True)
         return updated_plugins
 
     def init_plugins(self) -> None:
@@ -143,7 +133,7 @@ class PluginManager(metaclass=Singleton):
                 continue
 
             try:
-                self.activate_plugin(plugin)
+                self.activate_plugin(plugin, init=True)
             except GajimPluginActivateException as error:
                 plugin.activatable = False
                 plugin.available_text = str(error)
@@ -180,10 +170,10 @@ class PluginManager(metaclass=Singleton):
                 return module_attr
         return None
 
-    def add_plugin(self,
-                   manifest: PluginManifest,
-                   activate: bool = False
-                   ) -> GajimPlugin | None:
+    def _add_plugin(self,
+                    manifest: PluginManifest,
+                    activate: bool = False
+                    ) -> GajimPlugin | None:
 
         plugin_class = self._load_plugin_module(manifest)
         if plugin_class is None:
@@ -216,7 +206,7 @@ class PluginManager(metaclass=Singleton):
 
         return plugin_obj
 
-    def remove_plugin(self, plugin: GajimPlugin) -> None:
+    def _remove_plugin(self, plugin: GajimPlugin) -> None:
         '''
         removes the plugin from the plugin list and deletes all loaded modules
         from sys. This way we will have a fresh start when the plugin gets added
@@ -416,29 +406,33 @@ class PluginManager(metaclass=Singleton):
                 for handler in instance.handlers:
                     client.connection.unregister_handler(handler)
 
-    def activate_plugin(self, plugin: GajimPlugin) -> None:
+    def activate_plugin(self, plugin: GajimPlugin, init: bool = False) -> None:
         '''
         :param plugin: plugin to be activated
         :type plugin: class object of `GajimPlugin` subclass
         '''
-        if not plugin.active and plugin.activatable:
+        if plugin.active or not plugin.activatable:
+            return
 
-            self._add_gui_extension_points_handlers_from_plugin(plugin)
-            self._add_encryption_name_from_plugin(plugin)
-            self._handle_all_gui_extension_points_with_plugin(plugin)
-            self._register_events_handlers_in_ged(plugin)
-            self._register_modules_with_handlers(plugin)
+        self._add_gui_extension_points_handlers_from_plugin(plugin)
+        self._add_encryption_name_from_plugin(plugin)
+        self._handle_all_gui_extension_points_with_plugin(plugin)
+        self._register_events_handlers_in_ged(plugin)
+        self._register_modules_with_handlers(plugin)
 
-            self.active_plugins.append(plugin)
-            try:
-                plugin.activate()
-            except GajimPluginException as e:
-                self.deactivate_plugin(plugin)
-                raise GajimPluginActivateException(str(e))
-            app.settings.set_plugin_setting(plugin.manifest.short_name,
-                                            'active',
-                                            True)
-            plugin.active = True
+        self.active_plugins.append(plugin)
+        try:
+            plugin.activate()
+        except GajimPluginException as e:
+            self.deactivate_plugin(plugin)
+            raise GajimPluginActivateException(str(e))
+        app.settings.set_plugin_setting(plugin.manifest.short_name,
+                                        'active',
+                                        True)
+        plugin.active = True
+
+        if not init:
+            app.commands.init()
 
     def deactivate_plugin(self, plugin: GajimPlugin) -> None:
         # remove GUI extension points handlers (provided by plug-in) from
@@ -477,6 +471,7 @@ class PluginManager(metaclass=Singleton):
                                         'active',
                                         False)
         plugin.active = False
+        app.commands.init()
 
     def _add_gui_extension_points_handlers_from_plugin(self,
                                                        plugin: GajimPlugin
@@ -545,7 +540,11 @@ class PluginManager(metaclass=Singleton):
                     continue
 
                 if not manifest.is_usable:
-                    log.info('Skipped plugin with not suitable requirements')
+                    log.info(
+                        'Skipped plugin with not suitable requirements: %s %s',
+                        manifest.short_name,
+                        manifest.requirements
+                    )
                     continue
 
                 same_plugin = manifests.get(manifest.short_name)
@@ -558,7 +557,7 @@ class PluginManager(metaclass=Singleton):
                 manifests[manifest.short_name] = manifest
 
         for manifest in manifests.values():
-            self.add_plugin(manifest)
+            self._add_plugin(manifest)
 
     def install_from_zip(self,
                          zip_filename: str,
@@ -615,7 +614,7 @@ class PluginManager(metaclass=Singleton):
             rmtree(plugin_path)
             raise PluginsystemError(_('Installation failed'))
 
-        return self.add_plugin(manifest)
+        return self._add_plugin(manifest)
 
     def delete_plugin_files(self, plugin_path: Path) -> None:
         def _on_error(func: Callable[..., Any],
@@ -639,7 +638,7 @@ class PluginManager(metaclass=Singleton):
         if not plugin:
             return
 
-        self.remove_plugin(plugin)
+        self._remove_plugin(plugin)
         self.delete_plugin_files(Path(plugin.__path__))
         if not is_shipped_plugin(Path(plugin.__path__)):
             path = configpaths.get('PLUGINS_BASE') / plugin.manifest.short_name
